# HslCommunication

A paid industrial Internet of Things underlying architecture framework, focusing on the underlying technical communication, like PLC, Robot, Modbus, Redis, Mqtt, WebSocket, socket, etc.

什么是HSL？  
     这是一个基于工业物联网，计算机通讯的架构实现，集成了工业软件开发的大部分的基础功能实现，比如三菱PLC通讯，西门子PLC通讯，欧姆龙PLC通讯，modbus通讯，AB PLC通讯等等，这些通讯全部进行了多语言的实现，当然，主打的 .net 库的功能集成还更加的强大，除此之外，还实现了跨程序，跨语言，跨平台的通讯，让你不再纠结于使用windows还是 linux系统，实现了日志功能，流水号生成功能，邮件发送功能，傅立叶变换功能，等等，将来会集成更多的工业环境常见功能的实现。  为了不让工业4.0只停留在口号上，万丈高楼平地起，而基石就是HSL。  

HSL能干什么？ 
     HSL能将工业生产现场的设备进行万物互联，将数据在底层自由的传输，无论是主动的还是被动的，无论你的采集系统是什么（通常采集系统为windows电脑，或是嵌入式系统，或是基于linux的盒子）， 都可以实现数据的随意传输，方便快速实现强大，实时，高响应的健壮系统，无论您是构建C/S系统，还是B/S系统，还是C-B-S-A（集成桌面客户端，浏览器，安卓）混合系统，都是快速而且低成本的实现， 只要拥有了工业现场的一手数据，即可以搭建强大的实时监视功能的软件，生产报表及自动化排产的软件，各种工艺参数历史追踪的软件，基于数据经验的机器学习软件，以及全功能等等。  顺便聊聊 ，传统的工业模式都是采购现成的工业软件，包括上位机软件及MES系统，而忽视了自身的研发能力。对于一些行业标准的功能软件来说，比如ERP系统，财务软件，这些可以直接采购即可， 但是对于上位机及MES系统而言，各个企业的实际需求千差万别，难以有通用的场景，而目前的现状都是花大钱办小事，所以在此处，给出一条面向未来的模式实现：对于生产企业而言， 基于HSL开发企业级MES系统实现，作为数据的核心仓库中心，及业务逻辑处理中心；对于设备供应商而言，基于HSL开发上位机软件系统，快速且方便的将数据分发至客户的MES系统，进行协同工作。 

     企业合作： 欢迎企业客户联系合作，包括开发新的协议支持，培训及指导上位机软件及MES系统的开发，指导工厂智能化升级改造及信息化团队建设。
